estimateMSVmetrics-methods: Estimates the GPD and SPOmulti-source variability metrics and...

Description Usage Arguments Value

Description

Estimates the GPD and SPOmulti-source variability metrics and the corresponding source projection vertices from a matrix of probability distributions of different data sources

Usage

1
estimateMSVmetrics(msvMetrics, nBySource, idSource)

Arguments

probabilities

m-by-n matrix containing the probability mass of n data sources on m distribution bins

Value

A list containing the following results: GPD the value of the Global Probabilistic Deviation metric, where 0 means equal distributions and 1 means non-overlapping distributions SPOs the values of Source Probabilistic Outlyingness for each data source, where 0 means equal to central tendency and 1 completely non-overlapping Vertices a n-by-(n-1) matrix containing the coordinates of each data source in the projected probabilistic space conserving their dissimilarities, e.g, for 3D projections the 3 first columns can be used


carsaesi/EHRsourceVariability documentation built on June 6, 2019, 7:52 a.m.